==> Gh-Robots-0.0.4.8.tar.gz: Gh-Robots-0.0.4.8/README.md <==
# Gh-Robot

<p align="center">
<img src="https://cdn.api-go.asia/assets/img/Robot.png" width="50" height="50">
</p>

<p align="center">A Github API-based Robot</p>


<p align="center">
<img src="https://img.shields.io/github/license/CoolPlayLin/Gh-Robot?style=flat-square">
<img src="https://img.shields.io/pypi/dm/Gh-Robot?style=flat-square">
<img src="https://img.shields.io/pypi/v/Gh-Robots?style=flat-square">
<img src="https://img.shields.io/github/issues-pr/CoolPlayLin/Gh-Robot?style=flat-square">
</p>

##  **Installation**

- ### **Online Installation(Recommend)** 👍

**Pypi**

```
pip install Gh-Robots
```

**Aliyun**
```
pip install -i https://mirrors.aliyun.com/pypi/simple/ Gh-Robots
```

[More Mirror Station](https://github.com/coolplaylin/Gh-Robot/blob/main/docs/Mirror%20Station.md)

- ### Offline Installation 🤔

1. Clone
```
git clone https://github.com/coolplaylin/Gh-Robot
cd Gh-Robot
```

2. Install `SetupTool`
```
pip install setuptools
```

3. Install
```
python setup.py install
```

# Development Progress

**Developed Modules:**

- GhRepo
- GhRobot
- GhToCsv
- GhUser
- ShortCode
- CNetTool

# 🥰 Build

## Manual

### **Clone Repo**

```
git clone https://github.com/CoolPlayLin/Gh-Robot

cd Gh-Robot
```

### **Install Build**
```
pip install build
```

### **Build**
```
python -m build
```

## One-Click

[Linux](https://raw.githubusercontent.com/CoolPlayLin/Gh-Robot/main/Auto/build-linux.sh)
[Windows](https://raw.githubusercontent.com/CoolPlayLin/Gh-Robot/main/Auto/build-win.bat)

**Notes:**

- *Your Windows/Linux had to have Python & Git installed*
- *Your Python has to come with a pip package manager*

==> Gh-Robots-0.0.5.tar.gz: Gh-Robots-0.0.5/README.md <==
# Gh-Robot

<p align="center">
<img src="https://cdn.api-go.asia/assets/img/Robot.png" width="50" height="50">
</p>

<p align="center">A Github API-based Robot</p>


<p align="center">
<a href="https://github.com/CoolPlayLin/Gh-Robot/blob/main/LICENSE"><img src="https://img.shields.io/github/license/CoolPlayLin/Gh-Robot?style=flat-square"></a>
<img src="https://img.shields.io/pypi/dm/Gh-Robots?style=flat-square">
<a href="https://pypi.org/project/Gh-Robots/"><img src="https://img.shields.io/pypi/v/Gh-Robots?style=flat-square"></a>
<a href="https://github.com/CoolPlayLin/Gh-Robot/pulls"><img src="https://img.shields.io/github/issues-pr/CoolPlayLin/Gh-Robot?style=flat-square"></a>
</p>

##  **Installation**

- ### **Online Installation(Recommend)** 👍

**Pypi**

```
pip install Gh-Robots
```

**Aliyun**
```
pip install -i https://mirrors.aliyun.com/pypi/simple/ Gh-Robots
```

[More Mirror Station](https://github.com/coolplaylin/Gh-Robot/blob/main/docs/Mirror%20Station.md)

- ### Offline Installation 🤔

1. Clone
```
git clone https://github.com/coolplaylin/Gh-Robot
cd Gh-Robot
```

2. Install `SetupTool`
```
pip install setuptools
```

3. Install
```
python setup.py install
```

# Development Progress

**Developed Modules:**

- GhRepo
- GhRobot
- GhToCsv
- GhUser
- ShortCode
- CNetTool

# 🥰 Build

## Manual

### **Clone Repo**

```
git clone https://github.com/CoolPlayLin/Gh-Robot

cd Gh-Robot
```

### **Install Build**
```
pip install build
```

### **Build**
```
python -m build
```

## One-Click

[Linux](https://raw.githubusercontent.com/CoolPlayLin/Gh-Robot/main/Auto/build-linux.sh)
[Windows](https://raw.githubusercontent.com/CoolPlayLin/Gh-Robot/main/Auto/build-win.bat)

**Notes:**

- *Your Windows/Linux had to have Python & Git installed*
- *Your Python has to come with a pip package manager*
